package com.ruoyi.business.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TBaseGoodsMapper;
import com.ruoyi.business.domain.TBaseGoods;
import com.ruoyi.business.service.ITBaseGoodsService;
import com.ruoyi.common.core.text.Convert;

/**
 * 商品资料Service业务层处理
 * 
 * @author wms
 * @date 2022-05-09
 */
@Service
public class TBaseGoodsServiceImpl extends ServiceImpl<TBaseGoodsMapper, TBaseGoods> implements ITBaseGoodsService
{
    @Autowired
    private TBaseGoodsMapper tBaseGoodsMapper;

    /**
     * 查询商品资料
     * 
     * @param goodsId 商品资料主键
     * @return 商品资料
     */
    @Override
    public TBaseGoods selectTBaseGoodsByGoodsId(String goodsId)
    {
        return tBaseGoodsMapper.selectTBaseGoodsByGoodsId(goodsId);
    }

    /**
     * 查询商品资料列表
     * 
     * @param tBaseGoods 商品资料
     * @return 商品资料
     */
    @Override
    public List<TBaseGoods> selectTBaseGoodsList(TBaseGoods tBaseGoods)
    {
        return tBaseGoodsMapper.selectTBaseGoodsList(tBaseGoods);
    }

    /**
     * 新增商品资料
     * 
     * @param tBaseGoods 商品资料
     * @return 结果
     */
    @Override
    public int insertTBaseGoods(TBaseGoods tBaseGoods)
    {
        return tBaseGoodsMapper.insertTBaseGoods(tBaseGoods);
    }

    /**
     * 修改商品资料
     * 
     * @param tBaseGoods 商品资料
     * @return 结果
     */
    @Override
    public int updateTBaseGoods(TBaseGoods tBaseGoods)
    {
        return tBaseGoodsMapper.updateTBaseGoods(tBaseGoods);
    }

    /**
     * 批量删除商品资料
     * 
     * @param goodsIds 需要删除的商品资料主键
     * @return 结果
     */
    @Override
    public int deleteTBaseGoodsByGoodsIds(String goodsIds)
    {
        return tBaseGoodsMapper.deleteTBaseGoodsByGoodsIds(Convert.toStrArray(goodsIds));
    }

    /**
     * 删除商品资料信息
     * 
     * @param goodsId 商品资料主键
     * @return 结果
     */
    @Override
    public int deleteTBaseGoodsByGoodsId(String goodsId)
    {
        return tBaseGoodsMapper.deleteTBaseGoodsByGoodsId(goodsId);
    }
}
